==> ejc-middlemeasurement-impl-3.0.0-20220412.090131-33-sources.jar: com/ejianc/business/middlemeasurement/vo/RevolvingleasedetailVO.java <==
package com.ejianc.business.middlemeasurement.vo;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 月度周转工具租赁费结算单子表
 * 
 * @author generator
 * 
 */
public class RevolvingleasedetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.String sort; // 序号
    private java.lang.String materialCode; // 物资编码
    private java.lang.String lesseeMaterialsName; // 租赁物资名称
    private java.lang.String specifications; // 规格型号
    private java.lang.String measurementUnit; // 计量单位
    private java.lang.Integer lesseeQuantity; // 租赁数量
    private java.util.Date settleTime; // 本期计算起始时间
    private java.lang.String settleTimeShow; // 本期计算起始时间
    private java.util.Date endTime; // 本期计算终止时间
    private java.lang.String endTimeShow; // 本期计算终止时间
    private java.lang.Integer lesseeTerm; // 本期租赁期长(天)
    private java.math.BigDecimal lesseeUnitprice; // 租赁单价(除税)(元)
    private java.math.BigDecimal taxLesseeUnitprice; // 租赁单价(含税)(元)
    private java.math.BigDecimal lesseeTotalprice; // 租赁合价(除税)(元)
    private java.math.BigDecimal taxLesseeTotalprice; // 租赁合价(含税)(元)
    private java.math.BigDecimal lossDamage; // 丢失损坏量
    private java.math.BigDecimal compensateUnitprice; // 赔偿单价(除税)(元)
    private java.math.BigDecimal taxCompensateUnitprice; // 赔偿单价(含税)(元)
    private java.math.BigDecimal compensateAccount; // 赔偿金额((除税)(元)
    private java.math.BigDecimal taxCompensateAccount; // 赔偿金额(含税)(元)
    private java.math.BigDecimal otherExpenses; // 清理维修费非等其他费用(除税)(元)
    private java.math.BigDecimal taxOtherExpenses; // 清理维修费非等其他费用(含税)(元)
    private java.math.BigDecimal monthlyExpenses; // 月度结算费用((除税)(元)
    private java.math.BigDecimal taxMonthlyExpenses; // 月度结算费用(含税)(元)
    private java.lang.String remarks; // 备注
    private java.math.BigDecimal cumulativeAmount; // 累计结算金额((除税)
    private java.math.BigDecimal taxCumulativeAmount; // 累计结算金额(含税)
    private java.lang.Long materialCategoryId; // 物资分类id
    private java.lang.String materialCategoryName; // 物资分类名称
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private java.util.Date saveTime; // 保存时间
    private java.math.BigDecimal paymentProportion; // 合同付款比例
    

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 物资编码
     */
    public java.lang.String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物资编码
     */
    public void setMaterialCode(java.lang.String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 租赁物资名称
     */
    public java.lang.String getLesseeMaterialsName() {
        return lesseeMaterialsName;
    }

    /**
     * 租赁物资名称
     */
    public void setLesseeMaterialsName(java.lang.String lesseeMaterialsName) {
        this.lesseeMaterialsName = lesseeMaterialsName;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpecifications() {
        return specifications;
    }

    /**
     * 规格型号
     */
    public void setSpecifications(java.lang.String specifications) {
        this.specifications = specifications;
    }
    /**
     * 计量单位
     */
    public java.lang.String getMeasurementUnit() {
        return measurementUnit;
    }

    /**
     * 计量单位
     */
    public void setMeasurementUnit(java.lang.String measurementUnit) {
        this.measurementUnit = measurementUnit;
    }
    /**
     * 租赁数量
     */
    public java.lang.Integer getLesseeQuantity() {
        return lesseeQuantity;
    }

    /**
     * 租赁数量
     */
    public void setLesseeQuantity(java.lang.Integer lesseeQuantity) {
        this.lesseeQuantity = lesseeQuantity;
    }
    /**
     * 本期计算起始时间
     */
    public java.util.Date getSettleTime() {
        return settleTime;
    }

    /**
     * 本期计算起始时间
     */
    public void setSettleTime(java.util.Date settleTime) {
        this.settleTime = settleTime;
    }
    /**
     * 本期计算终止时间
     */
    public java.util.Date getEndTime() {
        return endTime;
    }

    /**
     * 本期计算终止时间
     */
    public void setEndTime(java.util.Date endTime) {
        this.endTime = endTime;
    }
    /**
     * 本期租赁期长(天)
     */
    public java.lang.Integer getLesseeTerm() {
        return lesseeTerm;
    }

    /**
     * 本期租赁期长(天)
     */
    public void setLesseeTerm(java.lang.Integer lesseeTerm) {
        this.lesseeTerm = lesseeTerm;
    }
    /**
     * 租赁单价(除税)(元)
     */
    public java.math.BigDecimal getLesseeUnitprice() {
        return lesseeUnitprice;
    }

    /**
     * 租赁单价(除税)(元)
     */
    public void setLesseeUnitprice(java.math.BigDecimal lesseeUnitprice) {
        this.lesseeUnitprice = lesseeUnitprice;
    }
    /**
     * 租赁单价(含税)(元)
     */
    public java.math.BigDecimal getTaxLesseeUnitprice() {
        return taxLesseeUnitprice;
    }

    /**
     * 租赁单价(含税)(元)
     */
    public void setTaxLesseeUnitprice(java.math.BigDecimal taxLesseeUnitprice) {
        this.taxLesseeUnitprice = taxLesseeUnitprice;
    }
    /**
     * 租赁合价(除税)(元)
     */
    public java.math.BigDecimal getLesseeTotalprice() {
        return lesseeTotalprice;
    }

    /**
     * 租赁合价(除税)(元)
     */
    public void setLesseeTotalprice(java.math.BigDecimal lesseeTotalprice) {
        this.lesseeTotalprice = lesseeTotalprice;
    }
    /**
     * 租赁合价(含税)(元)
     */
    public java.math.BigDecimal getTaxLesseeTotalprice() {
        return taxLesseeTotalprice;
    }

    /**
     * 租赁合价(含税)(元)
     */
    public void setTaxLesseeTotalprice(java.math.BigDecimal taxLesseeTotalprice) {
        this.taxLesseeTotalprice = taxLesseeTotalprice;
    }
    /**
     * 丢失损坏量
     */
    public java.math.BigDecimal getLossDamage() {
        return lossDamage;
    }

    /**
     * 丢失损坏量
     */
    public void setLossDamage(java.math.BigDecimal lossDamage) {
        this.lossDamage = lossDamage;
    }
    /**
     * 赔偿单价(除税)(元)
     */
    public java.math.BigDecimal getCompensateUnitprice() {
        return compensateUnitprice;
    }

    /**
     * 赔偿单价(除税)(元)
     */
    public void setCompensateUnitprice(java.math.BigDecimal compensateUnitprice) {
        this.compensateUnitprice = compensateUnitprice;
    }
    /**
     * 赔偿单价(含税)(元)
     */
    public java.math.BigDecimal getTaxCompensateUnitprice() {
        return taxCompensateUnitprice;
    }

    /**
     * 赔偿单价(含税)(元)
     */
    public void setTaxCompensateUnitprice(java.math.BigDecimal taxCompensateUnitprice) {
        this.taxCompensateUnitprice = taxCompensateUnitprice;
    }
    /**
     * 赔偿金额((除税)(元)
     */
    public java.math.BigDecimal getCompensateAccount() {
        return compensateAccount;
    }

    /**
     * 赔偿金额((除税)(元)
     */
    public void setCompensateAccount(java.math.BigDecimal compensateAccount) {
        this.compensateAccount = compensateAccount;
    }
    /**
     * 赔偿金额(含税)(元)
     */
    public java.math.BigDecimal getTaxCompensateAccount() {
        return taxCompensateAccount;
    }

    /**
     * 赔偿金额(含税)(元)
     */
    public void setTaxCompensateAccount(java.math.BigDecimal taxCompensateAccount) {
        this.taxCompensateAccount = taxCompensateAccount;
    }
    /**
     * 清理维修费非等其他费用(除税)(元)
     */
    public java.math.BigDecimal getOtherExpenses() {
        return otherExpenses;
    }

    /**
     * 清理维修费非等其他费用(除税)(元)
     */
    public void setOtherExpenses(java.math.BigDecimal otherExpenses) {
        this.otherExpenses = otherExpenses;
    }
    /**
     * 清理维修费非等其他费用(含税)(元)
     */
    public java.math.BigDecimal getTaxOtherExpenses() {
        return taxOtherExpenses;
    }

    /**
     * 清理维修费非等其他费用(含税)(元)
     */
    public void setTaxOtherExpenses(java.math.BigDecimal taxOtherExpenses) {
        this.taxOtherExpenses = taxOtherExpenses;
    }
    /**
     * 月度结算费用((除税)(元)
     */
    public java.math.BigDecimal getMonthlyExpenses() {
        return monthlyExpenses;
    }

    /**
     * 月度结算费用((除税)(元)
     */
    public void setMonthlyExpenses(java.math.BigDecimal monthlyExpenses) {
        this.monthlyExpenses = monthlyExpenses;
    }
    /**
     * 月度结算费用(含税)(元)
     */
    public java.math.BigDecimal getTaxMonthlyExpenses() {
        return taxMonthlyExpenses;
    }

    /**
     * 月度结算费用(含税)(元)
     */
    public void setTaxMonthlyExpenses(java.math.BigDecimal taxMonthlyExpenses) {
        this.taxMonthlyExpenses = taxMonthlyExpenses;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 累计结算金额((除税)
     */
    public java.math.BigDecimal getCumulativeAmount() {
        return cumulativeAmount;
    }

    /**
     * 累计结算金额((除税)
     */
    public void setCumulativeAmount(java.math.BigDecimal cumulativeAmount) {
        this.cumulativeAmount = cumulativeAmount;
    }
    /**
     * 累计结算金额(含税)
     */
    public java.math.BigDecimal getTaxCumulativeAmount() {
        return taxCumulativeAmount;
    }

    /**
     * 累计结算金额(含税)
     */
    public void setTaxCumulativeAmount(java.math.BigDecimal taxCumulativeAmount) {
        this.taxCumulativeAmount = taxCumulativeAmount;
    }

    public String getSettleTimeShow() {
        return settleTimeShow;
    }

    public void setSettleTimeShow(String settleTimeShow) {
        this.settleTimeShow = settleTimeShow;
    }

    public String getEndTimeShow() {
        return endTimeShow;
    }

    public void setEndTimeShow(String endTimeShow) {
        this.endTimeShow = endTimeShow;
    }

    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }

    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }

    public Date getSaveTime() {
        return saveTime;
    }

    public void setSaveTime(Date saveTime) {
        this.saveTime = saveTime;
    }

    public BigDecimal getPaymentProportion() {
        return paymentProportion;
    }

    public void setPaymentProportion(BigDecimal paymentProportion) {
        this.paymentProportion = paymentProportion;
    }
}

==> ejc-middlemeasurement-impl-3.0.0-20220428.022448-70-sources.jar: com/ejianc/business/middlemeasurement/vo/RevolvingleasedetailVO.java <==
package com.ejianc.business.middlemeasurement.vo;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.business.middlemeasurement.bean.RevolvingleasedetailEntity;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 月度周转工具租赁费结算单子表
 * 
 * @author generator
 * 
 */
public class RevolvingleasedetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.String sort; // 序号
    private java.lang.String materialCode; // 物资编码
    private java.lang.String lesseeMaterialsName; // 租赁物资名称
    private java.lang.String specifications; // 规格型号
    private java.lang.String measurementUnit; // 计量单位
    private java.lang.Integer lesseeQuantity; // 租赁数量
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date settleTime; // 本期计算起始时间
    private java.lang.String settleTimeShow; // 本期计算起始时间
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date endTime; // 本期计算终止时间
    private java.lang.String endTimeShow; // 本期计算终止时间
    private java.lang.Integer lesseeTerm; // 本期租赁期长(天)
    private java.math.BigDecimal lesseeUnitprice; // 租赁单价(除税)(元)
    private java.math.BigDecimal taxLesseeUnitprice; // 租赁单价(含税)(元)
    private java.math.BigDecimal lesseeTotalprice; // 租赁合价(除税)(元)
    private java.math.BigDecimal taxLesseeTotalprice; // 租赁合价(含税)(元)
    private java.math.BigDecimal lossDamage; // 丢失损坏量
    private java.math.BigDecimal compensateUnitprice; // 赔偿单价(除税)(元)
    private java.math.BigDecimal taxCompensateUnitprice; // 赔偿单价(含税)(元)
    private java.math.BigDecimal compensateAccount; // 赔偿金额((除税)(元)
    private java.math.BigDecimal taxCompensateAccount; // 赔偿金额(含税)(元)
    private java.math.BigDecimal otherExpenses; // 清理维修费非等其他费用(除税)(元)
    private java.math.BigDecimal taxOtherExpenses; // 清理维修费非等其他费用(含税)(元)
    private java.math.BigDecimal monthlyExpenses; // 月度结算费用((除税)(元)
    private java.math.BigDecimal taxMonthlyExpenses; // 月度结算费用(含税)(元)
    private java.lang.String remarks; // 备注
    private java.math.BigDecimal cumulativeAmount; // 累计结算金额((除税)
    private java.math.BigDecimal taxCumulativeAmount; // 累计结算金额(含税)
    private java.lang.Long materialCategoryId; // 物资分类id
    private java.lang.String materialCategoryCode; // 物资分类编码
    private java.lang.String materialCategoryName; // 物资分类名称
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private java.util.Date saveTime; // 保存时间
    private java.math.BigDecimal paymentProportion; // 合同付款比例

    private java.lang.String errorMsg;
    private List<RevolvingleasedetailEntity> revolvingleasedetailEntities = new ArrayList<>();

    public List<RevolvingleasedetailEntity> getRevolvingleasedetailEntities() {
        return revolvingleasedetailEntities;
    }

    public void setRevolvingleasedetailEntities(List<RevolvingleasedetailEntity> revolvingleasedetailEntities) {
        this.revolvingleasedetailEntities = revolvingleasedetailEntities;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 物资编码
     */
    public java.lang.String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物资编码
     */
    public void setMaterialCode(java.lang.String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 租赁物资名称
     */
    public java.lang.String getLesseeMaterialsName() {
        return lesseeMaterialsName;
    }

    /**
     * 租赁物资名称
     */
    public void setLesseeMaterialsName(java.lang.String lesseeMaterialsName) {
        this.lesseeMaterialsName = lesseeMaterialsName;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpecifications() {
        return specifications;
    }

    /**
     * 规格型号
     */
    public void setSpecifications(java.lang.String specifications) {
        this.specifications = specifications;
    }
    /**
     * 计量单位
     */
    public java.lang.String getMeasurementUnit() {
        return measurementUnit;
    }

    /**
     * 计量单位
     */
    public void setMeasurementUnit(java.lang.String measurementUnit) {
        this.measurementUnit = measurementUnit;
    }
    /**
     * 租赁数量
     */
    public java.lang.Integer getLesseeQuantity() {
        return lesseeQuantity;
    }

    /**
     * 租赁数量
     */
    public void setLesseeQuantity(java.lang.Integer lesseeQuantity) {
        this.lesseeQuantity = lesseeQuantity;
    }
    /**
     * 本期计算起始时间
     */
    public java.util.Date getSettleTime() {
        return settleTime;
    }

    /**
     * 本期计算起始时间
     */
    public void setSettleTime(java.util.Date settleTime) {
        this.settleTime = settleTime;
    }
    /**
     * 本期计算终止时间
     */
    public java.util.Date getEndTime() {
        return endTime;
    }

    /**
     * 本期计算终止时间
     */
    public void setEndTime(java.util.Date endTime) {
        this.endTime = endTime;
    }
    /**
     * 本期租赁期长(天)
     */
    public java.lang.Integer getLesseeTerm() {
        return lesseeTerm;
    }

    /**
     * 本期租赁期长(天)
     */
    public void setLesseeTerm(java.lang.Integer lesseeTerm) {
        this.lesseeTerm = lesseeTerm;
    }
    /**
     * 租赁单价(除税)(元)
     */
    public java.math.BigDecimal getLesseeUnitprice() {
        return lesseeUnitprice;
    }

    /**
     * 租赁单价(除税)(元)
     */
    public void setLesseeUnitprice(java.math.BigDecimal lesseeUnitprice) {
        this.lesseeUnitprice = lesseeUnitprice;
    }
    /**
     * 租赁单价(含税)(元)
     */
    public java.math.BigDecimal getTaxLesseeUnitprice() {
        return taxLesseeUnitprice;
    }

    /**
     * 租赁单价(含税)(元)
     */
    public void setTaxLesseeUnitprice(java.math.BigDecimal taxLesseeUnitprice) {
        this.taxLesseeUnitprice = taxLesseeUnitprice;
    }
    /**
     * 租赁合价(除税)(元)
     */
    public java.math.BigDecimal getLesseeTotalprice() {
        return lesseeTotalprice;
    }

    /**
     * 租赁合价(除税)(元)
     */
    public void setLesseeTotalprice(java.math.BigDecimal lesseeTotalprice) {
        this.lesseeTotalprice = lesseeTotalprice;
    }
    /**
     * 租赁合价(含税)(元)
     */
    public java.math.BigDecimal getTaxLesseeTotalprice() {
        return taxLesseeTotalprice;
    }

    /**
     * 租赁合价(含税)(元)
     */
    public void setTaxLesseeTotalprice(java.math.BigDecimal taxLesseeTotalprice) {
        this.taxLesseeTotalprice = taxLesseeTotalprice;
    }
    /**
     * 丢失损坏量
     */
    public java.math.BigDecimal getLossDamage() {
        return lossDamage;
    }

    /**
     * 丢失损坏量
     */
    public void setLossDamage(java.math.BigDecimal lossDamage) {
        this.lossDamage = lossDamage;
    }
    /**
     * 赔偿单价(除税)(元)
     */
    public java.math.BigDecimal getCompensateUnitprice() {
        return compensateUnitprice;
    }

    /**
     * 赔偿单价(除税)(元)
     */
    public void setCompensateUnitprice(java.math.BigDecimal compensateUnitprice) {
        this.compensateUnitprice = compensateUnitprice;
    }
    /**
     * 赔偿单价(含税)(元)
     */
    public java.math.BigDecimal getTaxCompensateUnitprice() {
        return taxCompensateUnitprice;
    }

    /**
     * 赔偿单价(含税)(元)
     */
    public void setTaxCompensateUnitprice(java.math.BigDecimal taxCompensateUnitprice) {
        this.taxCompensateUnitprice = taxCompensateUnitprice;
    }
    /**
     * 赔偿金额((除税)(元)
     */
    public java.math.BigDecimal getCompensateAccount() {
        return compensateAccount;
    }

    /**
     * 赔偿金额((除税)(元)
     */
    public void setCompensateAccount(java.math.BigDecimal compensateAccount) {
        this.compensateAccount = compensateAccount;
    }
    /**
     * 赔偿金额(含税)(元)
     */
    public java.math.BigDecimal getTaxCompensateAccount() {
        return taxCompensateAccount;
    }

    /**
     * 赔偿金额(含税)(元)
     */
    public void setTaxCompensateAccount(java.math.BigDecimal taxCompensateAccount) {
        this.taxCompensateAccount = taxCompensateAccount;
    }
    /**
     * 清理维修费非等其他费用(除税)(元)
     */
    public java.math.BigDecimal getOtherExpenses() {
        return otherExpenses;
    }

    /**
     * 清理维修费非等其他费用(除税)(元)
     */
    public void setOtherExpenses(java.math.BigDecimal otherExpenses) {
        this.otherExpenses = otherExpenses;
    }
    /**
     * 清理维修费非等其他费用(含税)(元)
     */
    public java.math.BigDecimal getTaxOtherExpenses() {
        return taxOtherExpenses;
    }

    /**
     * 清理维修费非等其他费用(含税)(元)
     */
    public void setTaxOtherExpenses(java.math.BigDecimal taxOtherExpenses) {
        this.taxOtherExpenses = taxOtherExpenses;
    }
    /**
     * 月度结算费用((除税)(元)
     */
    public java.math.BigDecimal getMonthlyExpenses() {
        return monthlyExpenses;
    }

    /**
     * 月度结算费用((除税)(元)
     */
    public void setMonthlyExpenses(java.math.BigDecimal monthlyExpenses) {
        this.monthlyExpenses = monthlyExpenses;
    }
    /**
     * 月度结算费用(含税)(元)
     */
    public java.math.BigDecimal getTaxMonthlyExpenses() {
        return taxMonthlyExpenses;
    }

    /**
     * 月度结算费用(含税)(元)
     */
    public void setTaxMonthlyExpenses(java.math.BigDecimal taxMonthlyExpenses) {
        this.taxMonthlyExpenses = taxMonthlyExpenses;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 累计结算金额((除税)
     */
    public java.math.BigDecimal getCumulativeAmount() {
        return cumulativeAmount;
    }

    /**
     * 累计结算金额((除税)
     */
    public void setCumulativeAmount(java.math.BigDecimal cumulativeAmount) {
        this.cumulativeAmount = cumulativeAmount;
    }
    /**
     * 累计结算金额(含税)
     */
    public java.math.BigDecimal getTaxCumulativeAmount() {
        return taxCumulativeAmount;
    }

    /**
     * 累计结算金额(含税)
     */
    public void setTaxCumulativeAmount(java.math.BigDecimal taxCumulativeAmount) {
        this.taxCumulativeAmount = taxCumulativeAmount;
    }

    public String getSettleTimeShow() {
        return settleTimeShow;
    }

    public void setSettleTimeShow(String settleTimeShow) {
        this.settleTimeShow = settleTimeShow;
    }

    public String getEndTimeShow() {
        return endTimeShow;
    }

    public void setEndTimeShow(String endTimeShow) {
        this.endTimeShow = endTimeShow;
    }

    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }

    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }

    public Date getSaveTime() {
        return saveTime;
    }

    public void setSaveTime(Date saveTime) {
        this.saveTime = saveTime;
    }

    public BigDecimal getPaymentProportion() {
        return paymentProportion;
    }

    public void setPaymentProportion(BigDecimal paymentProportion) {
        this.paymentProportion = paymentProportion;
    }

    public String getMaterialCategoryCode() {
        return materialCategoryCode;
    }

    public void setMaterialCategoryCode(String materialCategoryCode) {
        this.materialCategoryCode = materialCategoryCode;
    }
}
